@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
-'''Framework for releasing Python software with variable steps in the
-release process.
-'''
+"""Framework for releasing Python software with variable steps in the
+    release process.
+    """
 
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
@@ -16,20 +16,22 @@ from .regex import error_in_version
 
 
 class StopRelease(RuntimeError):
-    '''Release steps should raise this exception to stop the whole program.'''
+    """Release steps should raise this exception to stop the whole program."""
 
 
 @nine
 class ReleaseStep(object):
-    '''Abstract base class for release steps.'''
+    """Abstract base class for release steps."""
+
     ERROR_CODE = 1
     success = None
     stop_on_failure = True
 
     def __call__(self):
-        '''Override this method to do the main work of the release step.
+        """Override this method to do the main work of the release step.
+
         On error, StopRelease should be raised.
-        '''
+        """
         raise StopRelease('Step not implemented.')
 
     def _succeed(self):
@@ -83,12 +85,15 @@ class ReleaseStep(object):
 
 
 class CommandStep(ReleaseStep):
-    '''Abstract base class for release steps... that executes a command.'''
+    """Abstract base class for any release step that runs a command."""
+
     def __call__(self):
         self._execute_or_complain(self.COMMAND)  # sets self.success
 
 
 class Releaser(object):
+    """Class the manages the whole release process."""
+
     def __init__(self, config, *steps):
         self.created_tags = []
         self.config = config
@@ -117,8 +122,9 @@ class Releaser(object):
             try:
                 step()
             except StopRelease as e:
-                self.log.critical('Release process stopped at step {0}:\n{1}'
-                    .format(step, e))
+                self.log.critical(
+                    'Release process stopped at step {0}:\n{1}'.format(
+                        step, e))
                 self.rewind()
                 from sys import exit
                 exit(step.ERROR_CODE)
@@ -131,7 +137,8 @@ class Releaser(object):
                     self.non_rewindable.append(step.no_rollback)
                 elif step.success and hasattr(step, 'rollback'):
                     self.rewindable.append(step)
-        self.log.info('Successfully released version {0}. '
+        self.log.info(
+            'Successfully released version {0}. '
             'Sorry for the convenience, mcdonc!'.format(self.the_version))
 
     def rewind(self):
@@ -152,8 +159,8 @@ class Releaser(object):
             try:
                 step.rollback()
             except Exception as e:
-                self.log.error('Could not roll back step {0}:\n{1}'
-                    .format(step, str(e)))
+                self.log.error('Could not roll back step {0}:\n{1}'.format(
+                    step, str(e)))
 
     _old_version = None    # 0.1.2dev (exists when the program starts)
     _the_version = None    # 0.1.2    (the version being released)
@@ -184,7 +191,7 @@ class Releaser(object):
         self.log.debug('Version being released: {0}'.format(val))
 
     @property
-    def future_version(self):  # 0.1.3dev (development version after release)
+    def future_version(self):  # 0.1.3.dev1 (development version after release)
         parts = self.the_version.split('.')
         parts[-1] = str(int(parts[-1]) + 1)
-        return '.'.join(parts) + 'dev'
+        return '.'.join(parts) + '.dev1'
