@@ -6,19 +6,22 @@ import requests
 from bag.check_rst import check_rst_file
 from bag.console import bool_input
 from nine import filter, input, nine
-from path import path as pathpy
+from path import Path as pathpy  # TODO Switch to pathlib
 from . import ReleaseStep, StopRelease, CommandStep
 from .regex import version_in_python_source_file
 
-__all__ = ('Shell', 'CheckRstFiles', 'InteractivelyApproveDistribution',
-     'InteractivelyEnsureChangesDocumented', 'CheckTravis',
-    'SetVersionNumberInteractively', 'PypiRegister', 'PypiUpload',
-    'SetFutureVersion', 'ErrorStep')
+__all__ = (
+    'Shell', 'CheckRstFiles', 'InteractivelyApproveDistribution',
+    'InteractivelyApproveWheel', 'PypiUploadWheel',
+    'InteractivelyEnsureChangesDocumented', 'CheckTravis',
+    'SetVersionNumberInteractively', 'PypiUpload',
+    'SetFutureVersion', 'ErrorStep', 'Warn')
 
 
 @nine
 class Shell(ReleaseStep):
-    '''Runs some shell command.'''
+    """Runs some shell command."""
+
     ERROR_CODE = 2
 
     def __init__(self, command, stop_on_failure=True):
@@ -34,10 +37,12 @@ class Shell(ReleaseStep):
 
 
 class CheckRstFiles(ReleaseStep):
-    '''Helps keep documentation correct by verifying .rst documentation files.
-    If files are not provided to the constructor, recursively finds *.rst files
-    in the current directory and subdirectories.
-    '''
+    """Helps keep documentation correct by verifying .rst files.
+
+    If files are not provided to the constructor, recursively finds
+    *.rst files in the current directory and subdirectories.
+    """
+
     ERROR_CODE = 4
 
     def __init__(self, *files):
@@ -49,14 +54,14 @@ class CheckRstFiles(ReleaseStep):
             self.log.info('Checking ' + path)
             warnings = check_rst_file(path)
             if warnings:
-                raise StopRelease('There are errors in {0}:\n{1}'.format(path,
-                    '\n'.join([str(w) for w in warnings])))
+                raise StopRelease(
+                    'There are errors in {0}:\n{1}'.format(
+                        path, '\n'.join([str(w) for w in warnings])))
 
 
 class InteractivelyApproveDistribution(ReleaseStep):
-    '''Generate a source distribution and let the user verify that
-    all files are in there.
-    '''
+    """Generate a source distribution and let the user verify it."""
+
     ERROR_CODE = 5
 
     def __call__(self):
@@ -68,14 +73,33 @@ class InteractivelyApproveDistribution(ReleaseStep):
         print("your chance to open the new archive (in the 'dist' directory)")
         print("and check that all files are in there.")
         if not bool_input("Do you approve the archive contents?"):
-            raise StopRelease('Source distribution content not approved.\n'
+            raise StopRelease(
+                'Source distribution content not approved.\n'
                 'If the distribution is missing some files,\n'
                 "try correcting your MANIFEST.in file according to\n"
                 "http://docs.python.org/3/distutils/sourcedist.html"
                 "#specifying-the-files-to-distribute")
 
 
+class InteractivelyApproveWheel(ReleaseStep):
+    """Generate wheel and let user verify it before proceeding."""
+
+    COMMAND = 'python setup.py bdist_wheel'
+    ERROR_CODE = 10
+
+    def __call__(self):
+        self._execute_or_complain(self.COMMAND)  # sets self.success
+        # TODO: Optionally xdg-open the wheel for convenience
+        print("A temporary wheel has been generated. Since it is just a\n"
+              "zip file, you should now open it (from the 'dist' directory)"
+              "\nand check that all files are in there.")
+        if not bool_input("Do you approve the wheel contents?"):
+            raise StopRelease('Wheel content not approved.')
+
+
 class InteractivelyEnsureChangesDocumented(ReleaseStep):
+    """Step that just bugs the user to verify the CHANGES file."""
+
     ERROR_CODE = 3
 
     def __call__(self):
@@ -86,9 +110,8 @@ class InteractivelyEnsureChangesDocumented(ReleaseStep):
 
 
 class CheckTravis(ReleaseStep):
-    '''Checks the status, on travis-ci.org, of the latest build of a
-    software project in a certain branch.
-    '''
+    """Check the status, on travis-ci.org, of the latest build."""
+
     ERROR_CODE = 91
     URL = 'https://api.travis-ci.org/repos/' \
           '{github_user}/{github_repository}/builds'
@@ -113,15 +136,14 @@ class CheckTravis(ReleaseStep):
 
 
 class SetVersionNumberInteractively(ReleaseStep):
-    '''Asks the user for the new version number and writes it onto
-    the configured source code file.
-    '''
+    """Ask user for the new version number and write it on the source code."""
+
     ERROR_CODE = 6
 
     def __call__(self):
         releaser = self.releaser
         path = releaser.config['version_file']
-        keyword = releaser.config['version_keyword']
+        keyword = releaser.config.get('version_keyword', 'version')
         releaser.old_version = version_in_python_source_file(
             path, keyword=keyword)
         print('Current version: {0}'.format(releaser.old_version))
@@ -132,17 +154,9 @@ class SetVersionNumberInteractively(ReleaseStep):
         self._succeed()
 
 
-class PypiRegister(CommandStep):
-    COMMAND = 'python setup.py register'
-    ERROR_CODE = 7
-    no_rollback = 'The release has been created on http://pypi.python.org.\n' \
-        'Unfortunately, the release must be removed manually.'
-
-    def _validate_command_output(self, command_output):
-        return "Server response (200): OK" in command_output
-
-
 class PypiUpload(CommandStep):
+    """Generate a source distribution and send it to pypi."""
+
     COMMAND = 'python setup.py sdist upload'
     ERROR_CODE = 8
     no_rollback = 'Cannot roll back the sdist upload to http://pypi.python.org'
@@ -151,29 +165,56 @@ class PypiUpload(CommandStep):
         return "Server response (200): OK" in command_output
 
 
+class PypiUploadWheel(CommandStep):
+    """Generate wheel and upload it to pypi."""
+
+    COMMAND = 'python setup.py bdist_wheel upload'
+
+    # COMMAND = 'python setup.py upload'
+    # ...fails with "error: No dist file created in earlier command"
+
+    ERROR_CODE = 11
+    no_rollback = 'Cannot roll back the wheel upload to http://pypi.python.org'
+
+    def _validate_command_output(self, command_output):
+        return "Server response (200): OK" in command_output
+
+
 class SetFutureVersion(ReleaseStep):
-    '''Replaces the version number in the configured source code file with
-    the future version number (the one ending in 'dev').
-    '''
+    """Set the development version number in source code after release."""
+
     ERROR_CODE = 9
 
     def __call__(self):
         releaser = self.releaser
         path = releaser.config['version_file']
-        keyword = releaser.config['version_keyword']
+        keyword = releaser.config.get('version_keyword', 'version')
         # If the SetVersionNumberInteractively step is disabled for debugging,
         # we can still execute the current step, by populating the_version:
         if releaser.the_version is None:
             releaser._the_version = version_in_python_source_file(
                 path, keyword=keyword)
-        self.log.info('Ready for the next development cycle! Setting version '
-              + releaser.future_version)
+        self.log.info(
+            'Ready for the next development cycle! Setting version ' +
+            releaser.future_version)
         version_in_python_source_file(
             path, keyword=keyword, replace=releaser.future_version)
         self._succeed()
 
 
 class ErrorStep(CommandStep):
-    '''Raises an exception to force a rollback. Good for testing.'''
+    """Raise an exception to force a rollback. Good for testing."""
+
     COMMAND = 'thisCommandDontExist'
     ERROR_CODE = 255
+
+
+class Warn(ReleaseStep):
+    """Just print a warning on the screen and on the log file."""
+
+    def __init__(self, msg):
+        self.msg = msg
+
+    def __call__(self):
+        self.log.warn(self.msg)
+        self.success = True
